@@ -17,20 +17,23 @@ import (
 	"strings"
 	"testing"
 
-	yaml "gopkg.in/yaml.v2"
+	"github.com/prometheus/common/promslog"
+	"go.yaml.in/yaml/v2"
 )
 
+var nopLogger = promslog.NewNopLogger()
+
 func TestHideConfigSecrets(t *testing.T) {
 	sc := &SafeConfig{}
-	err := sc.ReloadConfig([]string{"testdata/snmp-auth.yml"}, false)
+	err := sc.ReloadConfig(nopLogger, []string{"testdata/snmp-auth.yml"}, false)
 	if err != nil {
 		t.Errorf("Error loading config %v: %v", "testdata/snmp-auth.yml", err)
 	}
 
 	// String method must not reveal authentication credentials.
-	sc.RLock()
+	sc.mu.RLock()
 	c, err := yaml.Marshal(sc.C)
-	sc.RUnlock()
+	sc.mu.RUnlock()
 	if err != nil {
 		t.Errorf("Error marshaling config: %v", err)
 	}
@@ -41,13 +44,13 @@ func TestHideConfigSecrets(t *testing.T) {
 
 func TestLoadConfigWithOverrides(t *testing.T) {
 	sc := &SafeConfig{}
-	err := sc.ReloadConfig([]string{"testdata/snmp-with-overrides.yml"}, false)
+	err := sc.ReloadConfig(nopLogger, []string{"testdata/snmp-with-overrides.yml"}, false)
 	if err != nil {
 		t.Errorf("Error loading config %v: %v", "testdata/snmp-with-overrides.yml", err)
 	}
-	sc.RLock()
+	sc.mu.RLock()
 	_, err = yaml.Marshal(sc.C)
-	sc.RUnlock()
+	sc.mu.RUnlock()
 	if err != nil {
 		t.Errorf("Error marshaling config: %v", err)
 	}
@@ -56,13 +59,13 @@ func TestLoadConfigWithOverrides(t *testing.T) {
 func TestLoadMultipleConfigs(t *testing.T) {
 	sc := &SafeConfig{}
 	configs := []string{"testdata/snmp-auth.yml", "testdata/snmp-with-overrides.yml"}
-	err := sc.ReloadConfig(configs, false)
+	err := sc.ReloadConfig(nopLogger, configs, false)
 	if err != nil {
 		t.Errorf("Error loading configs %v: %v", configs, err)
 	}
-	sc.RLock()
+	sc.mu.RLock()
 	_, err = yaml.Marshal(sc.C)
-	sc.RUnlock()
+	sc.mu.RUnlock()
 	if err != nil {
 		t.Errorf("Error marshaling config: %v", err)
 	}
@@ -75,15 +78,15 @@ func TestEnvSecrets(t *testing.T) {
 	t.Setenv("ENV_PRIV_PASSWORD", "snmp_priv_password")
 
 	sc := &SafeConfig{}
-	err := sc.ReloadConfig([]string{"testdata/snmp-auth-envvars.yml"}, true)
+	err := sc.ReloadConfig(nopLogger, []string{"testdata/snmp-auth-envvars.yml"}, true)
 	if err != nil {
 		t.Errorf("Error loading config %v: %v", "testdata/snmp-auth-envvars.yml", err)
 	}
 
 	// String method must not reveal authentication credentials.
-	sc.RLock()
+	sc.mu.RLock()
 	c, err := yaml.Marshal(sc.C)
-	sc.RUnlock()
+	sc.mu.RUnlock()
 	if err != nil {
 		t.Errorf("Error marshaling config: %v", err)
 	}
@@ -106,7 +109,7 @@ func TestEnvSecretsMissing(t *testing.T) {
 	t.Setenv("ENV_PRIV_PASSWORD", "snmp_priv_password")
 
 	sc := &SafeConfig{}
-	err := sc.ReloadConfig([]string{"testdata/snmp-auth-envvars.yml"}, true)
+	err := sc.ReloadConfig(nopLogger, []string{"testdata/snmp-auth-envvars.yml"}, true)
 	if err != nil {
 		// we check the error message pattern to determine the error
 		if strings.Contains(err.Error(), "environment variable not found") {
@@ -120,7 +123,7 @@ func TestEnvSecretsMissing(t *testing.T) {
 // When SNMPv2 was specified without credentials
 func TestEnvSecretsNotSpecified(t *testing.T) {
 	sc := &SafeConfig{}
-	err := sc.ReloadConfig([]string{"testdata/snmp-auth-v2nocreds.yml"}, true)
+	err := sc.ReloadConfig(nopLogger, []string{"testdata/snmp-auth-v2nocreds.yml"}, true)
 	if err != nil {
 		t.Errorf("Error loading config %v: %v", "testdata/snmp-auth-v2nocreds.yml", err)
 	}
