@@ -34,7 +34,7 @@ import (
 	"github.com/prometheus/common/version"
 	"github.com/prometheus/exporter-toolkit/web"
 	webflag "github.com/prometheus/exporter-toolkit/web/kingpinflag"
-	yaml "gopkg.in/yaml.v2"
+	"go.yaml.in/yaml/v2"
 
 	"github.com/prometheus/snmp_exporter/collector"
 	"github.com/prometheus/snmp_exporter/config"
@@ -118,6 +118,13 @@ func handler(w http.ResponseWriter, r *http.Request, logger *slog.Logger, export
 		return
 	}
 
+	snmpEngineID := query.Get("snmp_engineid")
+	if len(query["snmp_engineid"]) > 1 {
+		http.Error(w, "'snmp_engineid' parameter must only be specified once", http.StatusBadRequest)
+		snmpRequestErrors.Inc()
+		return
+	}
+
 	queryModule := query["module"]
 	if len(queryModule) == 0 {
 		queryModule = append(queryModule, "if_mib")
@@ -125,7 +132,7 @@ func handler(w http.ResponseWriter, r *http.Request, logger *slog.Logger, export
 	uniqueM := make(map[string]bool)
 	var modules []string
 	for _, qm := range queryModule {
-		for _, m := range strings.Split(qm, ",") {
+		for m := range strings.SplitSeq(qm, ",") {
 			if m == "" {
 				continue
 			}
@@ -135,10 +142,10 @@ func handler(w http.ResponseWriter, r *http.Request, logger *slog.Logger, export
 			}
 		}
 	}
-	sc.RLock()
+	sc.mu.RLock()
 	auth, authOk := sc.C.Auths[authName]
 	if !authOk {
-		sc.RUnlock()
+		sc.mu.RUnlock()
 		http.Error(w, fmt.Sprintf("Unknown auth '%s'", authName), http.StatusBadRequest)
 		snmpRequestErrors.Inc()
 		return
@@ -147,17 +154,17 @@ func handler(w http.ResponseWriter, r *http.Request, logger *slog.Logger, export
 	for _, m := range modules {
 		module, moduleOk := sc.C.Modules[m]
 		if !moduleOk {
-			sc.RUnlock()
+			sc.mu.RUnlock()
 			http.Error(w, fmt.Sprintf("Unknown module '%s'", m), http.StatusBadRequest)
 			snmpRequestErrors.Inc()
 			return
 		}
 		nmodules = append(nmodules, collector.NewNamedModule(m, module))
 	}
-	sc.RUnlock()
+	sc.mu.RUnlock()
 	logger = logger.With("auth", authName, "target", target)
 	registry := prometheus.NewRegistry()
-	c := collector.New(r.Context(), target, authName, snmpContext, auth, nmodules, logger, exporterMetrics, *concurrency, debug)
+	c := collector.New(r.Context(), target, authName, snmpContext, snmpEngineID, auth, nmodules, logger, exporterMetrics, *concurrency, debug)
 	registry.MustRegister(c)
 	// Delegate http serving to Prometheus client library, which will call collector.Collect.
 	h := promhttp.HandlerFor(registry, promhttp.HandlerOpts{})
@@ -178,22 +185,22 @@ func updateConfiguration(w http.ResponseWriter, r *http.Request) {
 }
 
 type SafeConfig struct {
-	sync.RWMutex
-	C *config.Config
+	mu sync.RWMutex
+	C  *config.Config
 }
 
-func (sc *SafeConfig) ReloadConfig(configFile []string, expandEnvVars bool) (err error) {
-	conf, err := config.LoadFile(configFile, expandEnvVars)
+func (sc *SafeConfig) ReloadConfig(logger *slog.Logger, configFile []string, expandEnvVars bool) (err error) {
+	conf, err := config.LoadFile(logger, configFile, expandEnvVars)
 	if err != nil {
 		return err
 	}
-	sc.Lock()
+	sc.mu.Lock()
 	sc.C = conf
 	// Initialize metrics.
 	for module := range sc.C.Modules {
 		snmpCollectionDuration.WithLabelValues(module)
 	}
-	sc.Unlock()
+	sc.mu.Unlock()
 	return nil
 }
 
@@ -214,10 +221,20 @@ func main() {
 	prometheus.MustRegister(versioncollector.NewCollector("snmp_exporter"))
 
 	// Bail early if the config is bad.
-	err := sc.ReloadConfig(*configFile, *expandEnvVars)
+	err := sc.ReloadConfig(logger, *configFile, *expandEnvVars)
 	if err != nil {
 		logger.Error("Error parsing config file", "err", err)
-		logger.Error("Possible version missmatch between generator and snmp_exporter. Make sure generator and snmp_exporter are the same version.")
+		logger.Error("Possible version mismatch between generator and snmp_exporter. Make sure generator and snmp_exporter are the same version.")
+		logger.Error("See also: https://github.com/prometheus/snmp_exporter/blob/main/auth-split-migration.md")
+		os.Exit(1)
+	}
+	if len(sc.C.Modules) == 0 {
+		logger.Error("Configuration is missing Modules. Did you provide any configuration file?")
+		os.Exit(1)
+	}
+	if len(sc.C.Auths) == 0 {
+		logger.Error("Configuration is missing Auths.")
+		logger.Error("Possible version mismatch between generator and snmp_exporter. Make sure generator and snmp_exporter are the same version.")
 		logger.Error("See also: https://github.com/prometheus/snmp_exporter/blob/main/auth-split-migration.md")
 		os.Exit(1)
 	}
@@ -235,13 +252,13 @@ func main() {
 		for {
 			select {
 			case <-hup:
-				if err := sc.ReloadConfig(*configFile, *expandEnvVars); err != nil {
+				if err := sc.ReloadConfig(logger, *configFile, *expandEnvVars); err != nil {
 					logger.Error("Error reloading config", "err", err)
 				} else {
 					logger.Info("Loaded config file")
 				}
 			case rc := <-reloadCh:
-				if err := sc.ReloadConfig(*configFile, *expandEnvVars); err != nil {
+				if err := sc.ReloadConfig(logger, *configFile, *expandEnvVars); err != nil {
 					logger.Error("Error reloading config", "err", err)
 					rc <- err
 				} else {
@@ -356,9 +373,9 @@ func main() {
 	}
 
 	http.HandleFunc(configPath, func(w http.ResponseWriter, r *http.Request) {
-		sc.RLock()
+		sc.mu.RLock()
 		c, err := yaml.Marshal(sc.C)
-		sc.RUnlock()
+		sc.mu.RUnlock()
 		if err != nil {
 			logger.Error("Error marshaling configuration", "err", err)
 			http.Error(w, err.Error(), http.StatusInternalServerError)
